# Generated by hand to match the documented API.

export(lmvt)
export(simulate_scenario)

S3method(predict, lmvt)
S3method(print,   lmvt)
S3method(coef,    lmvt)
S3method(summary, lmvt)
S3method(print,   summary.lmvt)

importFrom(stats,
           coef, lm, lm.wfit, median, optim, pnorm, pt, quantile,
           rnorm, rt, sd, setNames, var)
importFrom(glmnet, glmnet, cv.glmnet)
